import { NgZone } from '@angular/core';
import { ApolloQueryResult, ObservableQuery, ApolloError, FetchMoreQueryOptions, FetchMoreOptions, SubscribeToMoreOptions, UpdateQueryOptions, ApolloCurrentQueryResult } from '@apollo/client/core';
import { Observable } from 'rxjs';
import { WatchQueryOptions, EmptyObject } from './types';
export declare class QueryRef<TData, TVariables = EmptyObject> {
    private obsQuery;
    valueChanges: Observable<ApolloQueryResult<TData>>;
    options: ObservableQuery<TData, TVariables>['options'];
    constructor(obsQuery: ObservableQuery<TData, TVariables>, ngZone: NgZone, options: WatchQueryOptions<TVariables>);
    get queryId(): ObservableQuery<TData, TVariables>['queryId'];
    get queryName(): ObservableQuery<TData, TVariables>['queryName'];
    get variables(): TVariables;
    result(): Promise<ApolloQueryResult<TData>>;
    getCurrentResult(): ApolloCurrentQueryResult<TData>;
    isDifferentFromLastResult(newResult: ApolloQueryResult<TData>): boolean;
    getLastResult(): ApolloQueryResult<TData>;
    getLastError(): ApolloError;
    resetLastResults(): void;
    refetch(variables?: TVariables): Promise<ApolloQueryResult<TData>>;
    fetchMore<K extends keyof TVariables>(fetchMoreOptions: FetchMoreQueryOptions<TVariables, K> & FetchMoreOptions<TData, TVariables>): Promise<ApolloQueryResult<TData>>;
    subscribeToMore<TMoreData = any, TMoreVariables = EmptyObject>(options: SubscribeToMoreOptions<TData, TMoreVariables, TMoreData>): () => void;
    updateQuery(mapFn: (previousQueryResult: TData, options: UpdateQueryOptions<TVariables>) => TData): void;
    stopPolling(): void;
    startPolling(pollInterval: number): void;
    setOptions(opts: any): Promise<void | ApolloQueryResult<TData>>;
    setVariables(variables: TVariables, tryFetch?: boolean, fetchResults?: boolean): Promise<void | ApolloQueryResult<TData>>;
}
